@@ -689,8 +689,12 @@ int EntryProc(void *arg)
     return util::WaitAllUntil(noPrivilegePid);
 }
 
-Container::Container(const std::string &bundle, const std::string &id, const Runtime &r)
-    : bundle(bundle)
+Container::Container(const std::string &bundle,
+                     const std::string &id,
+                     const std::string &stateDir,
+                     const Runtime &r)
+    : stateDir(stateDir)
+    , bundle(bundle)
     , id(id)
     , dd_ptr(new ContainerPrivate(r, bundle, this))
 {
@@ -742,13 +746,12 @@ int Container::Start()
     // FIXME: parent may dead before this return.
     prctl(PR_SET_PDEATHSIG, SIGKILL);
 
-    writeContainerJson(this->bundle, this->id, entryPid);
+    writeContainerJson(stateDir, this->bundle, this->id, entryPid);
 
     // FIXME(interactive bash): if need keep interactive shell
     auto ret = util::WaitAllUntil(entryPid);
 
-    auto dir =
-      std::filesystem::path("/run") / "user" / std::to_string(getuid()) / "linglong" / "box";
+    std::filesystem::path dir = stateDir;
     if (!std::filesystem::remove(dir / (this->id + ".json"))) {
         logErr() << "remove" << dir / (this->id + ".json") << "failed";
     }
