@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
-#ifndef LINGLONG_CLI_JSON_PRINTER_H_
-#define LINGLONG_CLI_JSON_PRINTER_H_
+#pragma once
 
 #include "linglong/cli/printer.h"
 
@@ -17,14 +16,17 @@ public:
     void printErr(const utils::error::Error &) override;
     void printPackage(const api::types::v1::PackageInfoV2 &) override;
     void printPackages(const std::vector<api::types::v1::PackageInfoV2> &) override;
+    void printPruneResult(const std::vector<api::types::v1::PackageInfoV2> &) override;
     void printContainers(const std::vector<api::types::v1::CliContainer> &) override;
     void printReply(const api::types::v1::CommonResult &) override;
     void printRepoConfig(const api::types::v1::RepoConfig &) override;
     void printLayerInfo(const api::types::v1::LayerInfo &) override;
-    void printTaskStatus(const QString &percentage, const QString &message, int status) override;
+    void printTaskState(double percentage,
+                        const QString &message,
+                        api::types::v1::State state,
+                        api::types::v1::SubState subState) override;
     void printContent(const QStringList &desktopPaths) override;
+    void printUpgradeList(std::vector<api::types::v1::UpgradeListResult> &) override;
 };
 
 } // namespace linglong::cli
-
-#endif
