@@ -4,13 +4,19 @@
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
-#ifndef LINGLONG_SRC_MODULE_REPO_CLIENT_FACTORY_H_
-#define LINGLONG_SRC_MODULE_REPO_CLIENT_FACTORY_H_
-#include "ClientApi.h"
+#pragma once
+
+extern "C" {
+#include "api/ClientAPI.h"
+}
+
+#include "linglong/utils/configure.h"
 
 #include <QObject>
 #include <QPoint>
 
+#include <memory>
+
 namespace linglong::repo {
 
 class ClientFactory : public QObject
@@ -20,13 +26,12 @@ public:
     ClientFactory(const QString &server);
     ClientFactory(const std::string &server);
 
-    QSharedPointer<api::client::ClientApi> createClient() const;
-
-    void setServer(QString server);
+    std::shared_ptr<apiClient_t> createClientV2();
+    void setServer(const QString &server);
+    void setServer(const std::string &server);
 
 private:
-    QString m_server;
+    std::string m_server;
+    std::string m_user_agent = "linglong/" LINGLONG_VERSION;
 };
 } // namespace linglong::repo
-
-#endif // LINGLONG_SRC_MODULE_REPO_CLIENT_FACTORY_H_
