@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
-#ifndef LINGLONG_RUNTIME_CONTAINER_H_
-#define LINGLONG_RUNTIME_CONTAINER_H_
+#pragma once
 
 #include "linglong/utils/error/error.h"
 #include "ocppi/cli/CLI.hpp"
@@ -32,5 +31,3 @@ private:
 };
 
 }; // namespace linglong::runtime
-
-#endif
