@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
-#ifndef LINGLONG_TEST_MODULE_CLI_FAKE_PRINTER_H_
-#define LINGLONG_TEST_MODULE_CLI_FAKE_PRINTER_H_
+#pragma once
 
 #include <gmock/gmock.h>
 
@@ -30,5 +29,3 @@ public:
 };
 
 } // namespace linglong::cli::test
-
-#endif // LINGLONG_TEST_MODULE_CLI_FAKE_PRINTER_H_
